@@ -5,8 +5,8 @@ import time
 from mjworker.variables import sync_pidfile, pid_files
 from mjworker.public import write_pid
 
-def check_process_status(pid_check_list):
-    failed_process = []
+def check_proc_status(pid_check_list):
+    failed_proc = []
     for pid_file in pid_check_list:
         with open(pid_file, 'r') as f:
             pid = int(f.readline())
@@ -14,16 +14,16 @@ def check_process_status(pid_check_list):
             f.close()
             if not pid_exists(pid):
                 pid_name = re.split('/|\.', pid_file[0])[-2]
-                failed_process.append(pid_name)
-    return failed_process
+                failed_proc.append(pid_name)
+    return failed_proc
 
 
 def sync_status(pid_check_list):
-    failed_process = check_process_status(pid_check_list)
-    if not len(failed_process):
+    failed_proc = check_proc_status(pid_check_list)
+    if not len(failed_proc):
         print('process check successful')
     else:
-        print(failed_process, 'process check error')
+        print(failed_proc, 'process check error')
 
 def sync_runner(master_data):
     write_pid(sync_pidfile)
