@@ -26,7 +26,7 @@ def post_task_status(hisId, jobState, jobResult, master_data):
         r = requests.post(url=url, json=data, headers=headers)
         response_text = json.loads(str(r.text))
         if response_text["statusCode"] == "00":
-            print("post task status successful")
+            print("post task status successful", hisId)
             return 0
         print("post task status failed: ", r.text)
     except Exception as e:
@@ -47,6 +47,7 @@ def get_task(master_data):
     else:
         if task["statusCode"] == "00":
             return r.text
+        print("get task failed: ", r.text)
         return False
 
 def task_timeout(func):
@@ -88,7 +89,6 @@ def task_producer(queue, master_data):
     while True:
         task = get_task(master_data)
         if not task:
-            print("get task failed:", task)
             continue
         print("---入队列: {}".format(task))
         queue.put(task)
